<?php
/**
* Plugin RoR
*
* @package	PLX
* @version	1.0
* @date	26/03/18
* @author Bronco
**/
class RoR extends plxPlugin {
	private $size;
	private $color_avatar;
	private $color_background;
	private $avatar_filename;
	private $admin;
	private $admin_html;
	private $avatar_html;

	public function __construct($default_lang) {
		# appel du constructeur de la classe plxPlugin (obligatoire)		
		parent::__construct($default_lang);
		
		$this->admin =$this->getParam("admin");		
		$this->size =intval($this->getParam("size"));	
		$this->color_avatar=$this->getParam("color_avatar");
		$this->color_background=$this->getParam("color_background");
		$this->avatar_html=$this->getParam("avatar_html");
		$this->admin_html=$this->getParam("admin_html");

		
		if (empty($this->admin_html)){
			$this->admin_html	=	'<div class="avatar %author"></div>';
		}

		if (empty($this->avatar_html)){
			$this->avatar_html	=	'<img class="avatar %author" src="%avatar"/>';
		}
		
		if (!empty($this->color_background)){
			$this->color_background	=$this->separatRGB($this->color_background)	;
		}

		if (!empty($this->color_avatar)){
			$this->color_avatar	=$this->separatRGB($this->color_avatar)	;
		}
		
		# limite l'acces a l'ecran de configuration du plugin
		# PROFIL_ADMIN , PROFIL_MANAGER , PROFIL_MODERATOR , PROFIL_EDITOR , PROFIL_WRITER
		$this->setConfigProfil(PROFIL_ADMIN);
		
		# Declaration d'un hook (existant ou nouveau)
		$this->addHook('showAvatar','showAvatar');		
	}

	# Activation / desactivation
	public function OnActivate() {
		# code à executer à l’activation du plugin
	}
	public function OnDeactivate() {
		# code à executer à la désactivation du plugin
	}
	

	########################################
	# HOOKS
	########################################


	########################################
	# showAvatar
	########################################
	# Description:
	public function showAvatar(){
		$plxMotor=plxMotor::getInstance();
		$avatars_folder=PLX_ROOT.$plxMotor->aConf['medias'].'avatars';
		if (!is_dir($avatars_folder)){mkdir($avatars_folder);}

		$string=$author=$plxMotor->plxRecord_coms->f('author');

		if ($author==$this->admin){
			echo $this->insert($author);
			return;
		}

		$this->avatar_filename=$this->size.$this->getParam("color_background").$this->getParam("color_avatar").'.png';
		$h1=hash('crc32',$string);
		$h2=hash('crc32b',$string);
		$current_avatar_color1=$this->color_avatar;
		$current_avatar_color2=$this->color_background;

		if (empty($current_avatar_color1)){
			$current_avatar_color1=$this->separatRGB($h2);
		}

		if (empty($current_avatar_color2)){
			$current_avatar_color2=$this->separatRGB($h1);
		}

		$string=$h1.$h2[0];
		$dotsize=$this->size/9;
		$this->avatar_filename=$avatars_folder.'/'.$string.$this->avatar_filename;

		if (is_file($this->avatar_filename)){
			echo $this->insert($author,$this->avatar_filename);
			return;
		}
		
		$image = @ImageCreate ($this->size, $this->size) or die ("Erreur lors de la création de l'image");
		$current_avatar_color1 = ImageColorAllocate ($image, $current_avatar_color1['r'], $current_avatar_color1['g'], $current_avatar_color1['b']);
		$current_avatar_color2 = ImageColorAllocate ($image, $current_avatar_color2['r'], $current_avatar_color2['g'], $current_avatar_color2['b']);

		$a[dechex(0)]='000010000';
		$a[dechex(16)]='111111111';

		for ($i=1;$i<=15;$i++){
			$bin=decbin($i);
			$bin=str_repeat('0', 4-strlen($bin)).$bin;
			$a[dechex($i)]=$bin.'1'.strrev($bin);
		}

		
		for ($linenb=0;$linenb<9;$linenb++){
			$pattern=$a[$string[$linenb]];
			for ($i=0;$i<9;$i++){
				$x=$i*$dotsize;
				$y=$linenb*$dotsize;
				if ($pattern[$i]==1){
					imagefilledrectangle ( $image ,$x , $y, $x+$dotsize, $y+$dotsize, $current_avatar_color1 );
				}else{
					imagefilledrectangle ( $image ,$x , $y, $x+$dotsize, $y+$dotsize, $current_avatar_color2);
				}
			}

		}
				
		ImagePng($image,$this->avatar_filename);
		chmod($this->avatar_filename,0644);
		echo $this->insert($author,$this->avatar_filename);
		return;
	}

	

	########################################
	# FUNCTIONS
	########################################
	private function insert($author,$src=''){
		if ($author==$this->admin){
			return str_replace(['%author','%avatar'],[$author,$src],$this->admin_html);
		}else{
			return str_replace(['%author','%avatar'],[$author,$src],$this->avatar_html);
		}
	}

	private function separatRGB($color){
	    $color=str_replace('#','',$color);
	    if (strlen($color)==3){
	        $color=$color[0].$color[0].$color[1].$color[1].$color[2].$color[2];
	    }
	    $RGB=array();
	    $RGB['r']=hexdec(substr($color, 0,2));
	    $RGB['g']=hexdec(substr($color, 2,2));
	    $RGB['b']=hexdec(substr($color, 4,2));  
	    return $RGB;
	}

	

}





/* Pense-bete:
 * Récuperer des parametres du fichier parameters.xml
 *	$this->getParam("<nom du parametre>")
 *	$this-> setParam ("param1", 12345, "numeric")
 *	$this->saveParams()
 *
 *	plxUtils::strCheck($string) : sanitize string
 *
 * 
 * Quelques constantes utiles: 
 * PLX_CORE
 * PLX_ROOT
 * PLX_CHARSET
 * PLX_PLUGINS
 * PLX_CONFIG_PATH
 * PLX_ADMIN (true si on est dans admin)
 * PLX_CHARSET
 * PLX_VERSION
 * PLX_FEED
 *
 * Appel de HOOK dans un thème
 *	eval($plxShow->callHook("ThemeEndHead","param1"))  ou eval($plxShow->callHook("ThemeEndHead",array("param1","param2")))
 *	ou $retour=$plxShow->callHook("ThemeEndHead","param1"));
 */